# Release history

### 1.0.1
* Remove biomapas/cicd-full image from pipelines.

### 1.0.0
* Upgrade CDK support from v1 to v2.
* Upgrade GitHub pipelines checkout version from v2 to v3.
* Set GitHub pipelines node version 18.
* Set GitHub pipelines python version 3.10.

### 0.0.4
* Increase the function timeout.

### 0.0.3
* Update boto3 requirement.

### 0.0.2
* Add more docstrings.

### 0.0.1
* Initial build.
